pub struct Marker {
ptr: WeakNodePtr,
}Expand description
A marker is a pointer to a node in the refinement tree that can be used to query information about that node or to move the cursor. A marker may become invalid if the underlying node is cleared.
Fields
ptr: WeakNodePtrImplementations