pub struct WKVarSubst {
pub subst_instantiations: UnordMap<WKVid, Vec<Expr>>,
pub wkvar_instantiations: UnordMap<WKVid, Binder<Expr>>,
pub keep_wkvars: bool,
}Fields
subst_instantiations: UnordMap<WKVid, Vec<Expr>>A map from wkvid to each of the substitutions we made for it in whatever we folded over.
In theory there should only ever be one value in this map.
wkvar_instantiations: UnordMap<WKVid, Binder<Expr>>keep_wkvars: boolKeep wkvars after substituting
Implementations